@@ -16,6 +16,6 @@ except ImportError:
     
 __version__ = __VERSION_STR__
 
-open = pak.open_pak
-load = pak.load_pak
-save = pak.save_pak
\ No newline at end of file
+open_pak = pak.open_pak
+load_pak = pak.load_pak
+save_pak = pak.save_pak
\ No newline at end of file
