@@ -7,14 +7,10 @@ import hashlib
 import pickle
 import contextlib
 import gzip
-from typing import Mapping
-
+from .utils import __VERSION__ as PAK_VERSION
 import cryptography
 from cryptography.fernet import Fernet
 
-PAK_VERSION = 1, 0, 0
-__file_cache = {}
-
 class PAK(SimpleNamespace):
     """This is the core of the PAK system. It is a recursive namespace that can be pickled and encrypted."""
     def __getattr__(self, item):
@@ -63,7 +59,6 @@ class PAK(SimpleNamespace):
     __setitem__ = SimpleNamespace.__setattr__
     __delitem__ = SimpleNamespace.__delattr__
 
-        
 def _sweep(pak):
     """Remove empty PAK objects from a PAK object."""
     for k, v in pak.__dict__.copy().items():
